@@ -53,24 +53,43 @@ class DriverMySQL():
             print(f"MySQL error: {e}")
             return False
         
-    def execute(self, query, params = None, commit = False):
+    def execute(self, query, params = None, commit = False, reconnect = True):
         '''
         Execute an SQL query.
         :param query: str
         :param params: tuple or dictionary params are bound to the variables in the operation. 
                        Specify variables using %s or %(name)s parameter style (that is, using format or pyformat style).
         :param commit: If True, commit INSERT/UPDATE/DELETE queries immediately.
+        :param reconnect: If True and the connection seems to have gone away, reconnect and retry the query.
         :return True/False
         '''
+        doRetry = False
         try:
             self.cursor.execute(query, params)
             if commit:
                 self.connection.commit()
-            return True
         except Error as e:
-            print(f"MySQL error: {e}")
-            print(query)
-            return False
+            if not reconnect:
+                print(f"MySQL error: {e}")
+                print(query)
+                return False
+            # this calls reconnect() internally:
+            self.connection.ping(reconnect = True, attempts = 2)
+            # get the cursor again:
+            self.cursor = self.connection.cursor()
+            doRetry = True
+
+        if doRetry:
+            # and retry the query
+            try:
+                self.cursor.execute(query, params)
+                if commit:
+                    self.connection.commit()
+            except Error as e:
+                print(f"MySQL error: {e}")
+                print(query)
+                return False
+        return True
     
     def commit(self):
         '''
